@@ -23,7 +23,7 @@ class ConsulService(object):
         for api in apis:
             uid = str(uuid.uuid4())
             suid = ''.join(uid.split("-"))
-            route_prefix = '{}.http.routers.{}'.format(prefix, suid)
+            route_prefix = "{}.http.routers.{}".format(prefix, suid)
             tags.append("{}.rule=Path(`{}`) && Method(`{}`)".format(route_prefix, api['path'], api['method']))
             key = None
             if 'scope' in api.keys():
@@ -31,7 +31,7 @@ class ConsulService(object):
             elif 'scopes' in api.keys():
                 key = 'scopes'
             if key is not None:
-                tags.append("{}.middleware=nezha@interval".format(route_prefix))
+                tags.append("{}.middlewares=nezha@internal".format(route_prefix))
                 tags.extend(["{}.metadata.nezha.scopes={}".format(route_prefix, scope) for scope in api[key].split(',')])
 
         logging.info("Tags:" + str(tags))
@@ -39,13 +39,13 @@ class ConsulService(object):
         self.registerService(app_name, app_id, local_ip, port, tags=tags, protocol=protocol,
                              health_entry=health_entry)
 
-        res = self.getService(app_name)
-        logging.info(str(res))
+        svc,res = self.getService(app_id)
+        logging.info(str(svc))
 
     def registerService(self, name, service_id, host, port, tags=None, protocol='http', health_entry='/health'):
         tags = tags or []
         url = "{}://{}:{}{}".format(protocol, host, port, health_entry)
-        logging.debug("Health Url: {}".format(url))
+        logging.info("Health Url: {}".format(url))
         # 注册服务
         self._consul.agent.service.register(
             name=name,
@@ -61,9 +61,9 @@ class ConsulService(object):
         return consul.Check.http("{}}://{}:{}{}".format(protocol, host, port, health_entry), interval, timeout,
                                  deregister, header)
 
-    def getService(self, name):
+    def getService(self, servie_id):
         services = self._consul.agent.services()
-        service = services.get(name)
+        service = services.get(servie_id)
         if not service:
             return None, None
         addr = "{0}:{1}".format(service['Address'], service['Port'])
@@ -78,21 +78,33 @@ if __name__ == '__main__':
     ip = Utility.getLocalIP(host="consul",port=8500)
     port = 8500
     api_entries = [
-        {
-            "desc": "获取老化车信息",
-            "path": "/api/v1.0/aging_car/info",
-            "method": "GET",
-            "scope": "mes:aging:get"
-        },
-        {
-            "desc": "获取老化信息",
-            "path": "/api/v1.0/aging/query",
-            "method": "GET",
-            "scopes": "mes:aging:get,mes:agi:get"
-        }
-    ]
+    {
+        "desc": "获取老化车信息",
+        "path": "/api/v1.0/aging_car/info",
+        "method": "GET",
+        "scope": "mes:aging:get"
+    },
+    {
+        "desc": "获取老化信息",
+        "path": "/api/v1.0/aging/query",
+        "method": "GET",
+        "scope": "mes:aging:get"
+    },
+    {
+        "desc": "序列号绑定老化车",
+        "path": "/api/v1.0/aging/sn_bind",
+        "method": "POST",
+        "scope": "mes:aging:post"
+    },
+    {
+        "desc": "工单绑定老化车",
+        "path": "/api/v1.0/aging/order_bind",
+        "method": "POST",
+        "scope": "mes:aging:post"
+    }
+]
     consulService = ConsulService("consul", 8500)
-    consulService.registerAPI(ip, 5000, 'jx-attandance-api-10-0-0-1','jx-attendance-api', 'traefik', 'inhand-poweris',
+    consulService.registerAPI("10.5.0.25", 5000,'jx-attendance-api','jx-attandance-api-10-0-0-1', 'traefik', 'inhand-poweris',
                               {'verison':'v1.0.0'}, api_entries, protocol='http',
                     health_entry='/health')
 
